# BlueeBees

![GitHub](https://img.shields.io/github/license/matheuswhite/bluebees.svg?style=popout)
[![Build Status](https://travis-ci.org/matheuswhite/bluebees.svg?branch=master)](https://travis-ci.org/matheuswhite/bluebees)
[![Requirements Status](https://requires.io/github/matheuswhite/bluebees/requirements.svg?branch=master)](https://requires.io/github/matheuswhite/bluebees/requirements/?branch=master)
[![codecov](https://codecov.io/gh/matheuswhite/bluebees/branch/master/graph/badge.svg)](https://codecov.io/gh/matheuswhite/bluebees)
[![Maintainability](https://api.codeclimate.com/v1/badges/47e7df71e0d21bc5b1c4/maintainability)](https://codeclimate.com/github/matheuswhite/bluebees/maintainability)

An app to help the usage of bluetooth mesh
